@@ -619,9 +619,9 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
             lambda o: solfege.app.handle_href('theory-intervals.html')),
           ('TreeEditor', None, _('_Edit Front Page'), None, None,
             self.do_tree_editor),
-          ('ExportTrainingSet', None, _('E_xport Exercises to Audio Files…'), None, None,
+          ('ExportTrainingSet', None, _(u'E_xport Exercises to Audio Files…'), None, None,
             self.new_training_set_editor),
-          ('EditPractiseSheet', None, _('Ear Training Test Pri_ntout…'), None, None,
+          ('EditPractiseSheet', None, _(u'Ear Training Test Pri_ntout…'), None, None,
             self.new_practisesheet_editor),
           ('OpenPreferencesWindow', 'gtk-preferences', None, '<ctrl>F12', None,
             self.open_preferences_window),
@@ -645,6 +645,8 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
             None, self.show_path_info),
           ('HelpOnline', None, _('_Mailing lists, web page etc.'), None, None,
             lambda o: solfege.app.handle_href('online-resources.html')),
+          ('HelpDonate', None, _('_Donate'), None, None,
+            lambda o: solfege.app.handle_href('http://www.solfege.org/Main/Donate')),
           ('HelpReportingBugs', None, _('Reporting _bugs'), None, None,
             lambda o: solfege.app.handle_href('bug-reporting.html')),
           ('HelpAbout', 'gtk-about', None, None, None, self.show_about_window),
