@@ -223,7 +223,7 @@ class DB(object):
                         """
                         d, f = os.path.split(filename)
                         fn = os.path.join(subdir, f)
-                        if (d == 'exercises%slesson-files' % os.sep
+                        if (d == 'exercises%sstandard%slesson-files' % (os.sep, os.sep)
                             and os.path.isfile(fn)):
                             return fn
                         return filename
